@@ -1,9 +1,11 @@
-from .split import split_job
 from .infer import infer_job
 from .draw import draw_job
 from .estimate import estimate_job
 
+from .check_stage import check_stage
+from .separate_stage import separate_stage
 from .load_stage import load_stage
 from .parse_stage import parse_stage
 from .fuse_stage import fuse_stage
+from .gather_stage import gather_stage
 from .pipeline_stage import pipeline_stage
