@@ -4,9 +4,9 @@ from intentron.utils import *
 
 def load_stage(src, dst):
     if osp.exists(dst):
-        log.info("Loading data is complete")
+        log.info("Loading is done")
     else:
-        log.info("Loading data has been started")
+        log.info("Loading started")
         touch(dst)
         flatpairs = get_flatpairs(src, dst)
         total = len(flatpairs)
